aboutsummaryrefslogtreecommitdiff
path: root/gdb
diff options
context:
space:
mode:
authorKevin Buettner <kevinb@redhat.com>2019-03-20 20:38:33 -0700
committerKevin Buettner <kevinb@redhat.com>2019-04-08 20:21:34 -0700
commit2b0c8b019996b23fb4717687f5e7ac8c5620c089 (patch)
tree27f4cf53d2e1f632def4eea8f081c92bdd22c88c /gdb
parentc369f8f0face23a06e0cf114bf70a024ba9b4959 (diff)
downloadgdb-2b0c8b019996b23fb4717687f5e7ac8c5620c089.zip
gdb-2b0c8b019996b23fb4717687f5e7ac8c5620c089.tar.gz
gdb-2b0c8b019996b23fb4717687f5e7ac8c5620c089.tar.bz2
Rename python function thread_from_thread_handle to thread_from_handle
This renaming was done to stay consistent with the naming of the new gdb.InferiorThread.handle method. I had initially named it "thread_handle" but Tom Tromey suggested just "handle". The old name (thread_from_thread_handle) still works, but is marked as deprecated in comments in the code as well as in the documentation. I have some code which uses these functions. I very much like the brevity of the new names. gdb/doc/ChangeLog: * python.texi (Inferiors In Python): Rename Inferior.thread_from_thread_handle to Inferior.thread_from_handle. Add note about the former being deprecated. gdb/ChangeLog: * python/py-inferior.c (infpy_thread_from_thread_handle): Adjust comments to reflect renaming of thread_from_thread_handle to thread_from_handle. Adjust keywords. Fix type error message. (inferior_object_methods): Add thread_from_handle. Retain thread_from_thread_handle, but mark it as deprecated. testsuite/ChangeLog: * gdb.python/py-thrhandle.exp: Adjust tests to call thread_from_handle instead of thread_from_thread_handle.
Diffstat (limited to 'gdb')
-rw-r--r--gdb/ChangeLog8
-rw-r--r--gdb/doc/ChangeLog6
-rw-r--r--gdb/doc/python.texi9
-rw-r--r--gdb/python/py-inferior.c12
-rw-r--r--gdb/testsuite/ChangeLog5
-rw-r--r--gdb/testsuite/gdb.python/py-thrhandle.exp30
6 files changed, 50 insertions, 20 deletions
diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 65be341..e1d20fd 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,5 +1,13 @@
2019-04-08 Kevin Buettner <kevinb@redhat.com>
+ * python/py-inferior.c (infpy_thread_from_thread_handle):
+ Adjust comments to reflect renaming of thread_from_thread_handle
+ to thread_from_handle. Adjust keywords. Fix type error message.
+ (inferior_object_methods): Add thread_from_handle. Retain
+ thread_from_thread_handle, but mark it as deprecated.
+
+2019-04-08 Kevin Buettner <kevinb@redhat.com>
+
* gdbthread.h (find_thread_by_handle): Revise declaration.
* thread.c (find_thread_by_handle): Likewise. Adjust
implementation too.
diff --git a/gdb/doc/ChangeLog b/gdb/doc/ChangeLog
index a3564ab..27e65ea 100644
--- a/gdb/doc/ChangeLog
+++ b/gdb/doc/ChangeLog
@@ -1,5 +1,11 @@
2019-04-08 Kevin Buettner <kevinb@redhat.com>
+ * python.texi (Inferiors In Python): Rename
+ Inferior.thread_from_thread_handle to Inferior.thread_from_handle.
+ Add note about the former being deprecated.
+
+2019-04-08 Kevin Buettner <kevinb@redhat.com>
+
* python.texi (Threads In Python): Add description for method
InferiorThread.handle.
diff --git a/gdb/doc/python.texi b/gdb/doc/python.texi
index 6a967ec..36947de 100644
--- a/gdb/doc/python.texi
+++ b/gdb/doc/python.texi
@@ -3000,11 +3000,16 @@ containing the address where the pattern was found, or @code{None} if
the pattern could not be found.
@end defun
+@findex Inferior.thread_from_handle
@findex Inferior.thread_from_thread_handle
-@defun Inferior.thread_from_thread_handle (thread_handle)
-Return the thread object corresponding to @var{thread_handle}, a thread
+@defun Inferior.thread_from_handle (handle)
+Return the thread object corresponding to @var{handle}, a thread
library specific data structure such as @code{pthread_t} for pthreads
library implementations.
+
+The function @code{Inferior.thread_from_thread_handle} provides
+the same functionality, but use of @code{Inferior.thread_from_thread_handle}
+is deprecated.
@end defun
@node Events In Python
diff --git a/gdb/testsuite/ChangeLog b/gdb/testsuite/ChangeLog
index 8c5739f..5f1ce3c 100644
--- a/gdb/testsuite/ChangeLog
+++ b/gdb/testsuite/ChangeLog
@@ -1,5 +1,10 @@
2019-04-08 Kevin Buettner <kevinb@redhat.com>
+ * gdb.python/py-thrhandle.exp: Adjust tests to call
+ thread_from_handle instead of thread_from_thread_handle.
+
+2019-04-08 Kevin Buettner <kevinb@redhat.com>
+
* gdb.python/py-thrhandle.exp: Add tests for
gdb.InferiorThread.handle.
diff --git a/gdb/testsuite/gdb.python/py-thrhandle.exp b/gdb/testsuite/gdb.python/py-thrhandle.exp
index 57b97fa..19c690b 100644
--- a/gdb/testsuite/gdb.python/py-thrhandle.exp
+++ b/gdb/testsuite/gdb.python/py-thrhandle.exp
@@ -16,7 +16,7 @@
# Please email any bugs, comments, and/or additions to this file to:
# bug-gdb@gnu.org
-# This file verifies that methods Inferior.thread_from_thread_handle
+# This file verifies that methods Inferior.thread_from_handle
# and InferiorThread.handle work as expected.
load_lib gdb-python.exp
@@ -67,44 +67,44 @@ gdb_test "info threads" \
{.*[\r\n]+\* +([0-9]+) +Thread[^\r\n]* do_something \(n=\1\) at.*}
# Check for expected results when passing a valid thread handle to
-# thread_from_thread_handle().
+# thread_from_handle().
-gdb_test "python print(gdb.selected_inferior().thread_from_thread_handle(gdb.parse_and_eval('thrs\[0\]')).num)" \
+gdb_test "python print(gdb.selected_inferior().thread_from_handle(gdb.parse_and_eval('thrs\[0\]')).num)" \
"1" "print thread id for thrs\[0\]"
-gdb_test "python print(gdb.selected_inferior().thread_from_thread_handle(gdb.parse_and_eval('thrs\[1\]')).num)" \
+gdb_test "python print(gdb.selected_inferior().thread_from_handle(gdb.parse_and_eval('thrs\[1\]')).num)" \
"2" "print thread id for thrs\[1\]"
-gdb_test "python print(gdb.selected_inferior().thread_from_thread_handle(gdb.parse_and_eval('thrs\[2\]')).num)" \
+gdb_test "python print(gdb.selected_inferior().thread_from_handle(gdb.parse_and_eval('thrs\[2\]')).num)" \
"3" "print thread id for thrs\[2\]"
# Objects which are of the correct size, but which are bogus thread
# handles should return None. For the first test (using thrs[3]), we
# use 0. For the second (thrs[4]), we use an unlikely bit pattern.
-gdb_test "python print(gdb.selected_inferior().thread_from_thread_handle(gdb.parse_and_eval('thrs\[3\]')))" \
+gdb_test "python print(gdb.selected_inferior().thread_from_handle(gdb.parse_and_eval('thrs\[3\]')))" \
"None" "print thread for bogus handle thrs\[3\]"
-gdb_test "python print(gdb.selected_inferior().thread_from_thread_handle(gdb.parse_and_eval('thrs\[4\]')))" \
+gdb_test "python print(gdb.selected_inferior().thread_from_handle(gdb.parse_and_eval('thrs\[4\]')))" \
"None" "print thread for bogus handle thrs\[4\]"
# We should see an exception when passing an object of the wrong type.
-gdb_test "python print(gdb.selected_inferior().thread_from_thread_handle(gdb.lookup_symbol('main')))" \
- ".*TypeError: Argument 'handle_obj' must be a thread handle object.*" \
- "TypeError when passing a symbol object to thread_from_thread_handle"
+gdb_test "python print(gdb.selected_inferior().thread_from_handle(gdb.lookup_symbol('main')))" \
+ ".*TypeError: Argument 'handle' must be a thread handle object.*" \
+ "TypeError when passing a symbol object to thread_from_handle"
# We should see an exception when passing too large of an object.
-gdb_test "python print(gdb.selected_inferior().thread_from_thread_handle(gdb.parse_and_eval('thrs')))" \
+gdb_test "python print(gdb.selected_inferior().thread_from_handle(gdb.parse_and_eval('thrs')))" \
".*Thread handle size mismatch.*" \
- "Pass overly large object to thread_from_thread_handle"
+ "Pass overly large object to thread_from_handle"
# We should see an exception when passing too small of an object.
-gdb_test "python print(gdb.selected_inferior().thread_from_thread_handle(gdb.parse_and_eval('\"S\"')))" \
+gdb_test "python print(gdb.selected_inferior().thread_from_handle(gdb.parse_and_eval('\"S\"')))" \
".*Thread handle size mismatch.*" \
- "Pass too small of an object to thread_from_thread_handle"
+ "Pass too small of an object to thread_from_handle"
# Test the thread_handle method
@@ -121,7 +121,7 @@ foreach thrN {0 1 2} {
1
gdb_py_test_silent_cmd \
- "python hand_bytes = inf.thread_from_thread_handle(hand).handle()" \
+ "python hand_bytes = inf.thread_from_handle(hand).handle()" \
"fetch thread handle from thread" \
1
diff --git a/gdb/python/py-inferior.c b/gdb/python/py-inferior.c
index 9109874..984cebb 100644
--- a/gdb/python/py-inferior.c
+++ b/gdb/python/py-inferior.c
@@ -755,7 +755,7 @@ infpy_is_valid (PyObject *self, PyObject *args)
Py_RETURN_TRUE;
}
-/* Implementation of gdb.Inferior.thread_from_thread_handle (self, handle)
+/* Implementation of gdb.Inferior.thread_from_handle (self, handle)
-> gdb.InferiorThread. */
static PyObject *
@@ -763,7 +763,7 @@ infpy_thread_from_thread_handle (PyObject *self, PyObject *args, PyObject *kw)
{
PyObject *handle_obj;
inferior_object *inf_obj = (inferior_object *) self;
- static const char *keywords[] = { "thread_handle", NULL };
+ static const char *keywords[] = { "handle", NULL };
INFPY_REQUIRE_VALID (inf_obj);
@@ -791,7 +791,7 @@ infpy_thread_from_thread_handle (PyObject *self, PyObject *args, PyObject *kw)
else
{
PyErr_SetString (PyExc_TypeError,
- _("Argument 'handle_obj' must be a thread handle object."));
+ _("Argument 'handle' must be a thread handle object."));
return NULL;
}
@@ -956,9 +956,15 @@ Write the given buffer object to the inferior's memory." },
METH_VARARGS | METH_KEYWORDS,
"search_memory (address, length, pattern) -> long\n\
Return a long with the address of a match, or None." },
+ /* thread_from_thread_handle is deprecated. */
{ "thread_from_thread_handle", (PyCFunction) infpy_thread_from_thread_handle,
METH_VARARGS | METH_KEYWORDS,
"thread_from_thread_handle (handle) -> gdb.InferiorThread.\n\
+Return thread object corresponding to thread handle.\n\
+This method is deprecated - use thread_from_handle instead." },
+ { "thread_from_handle", (PyCFunction) infpy_thread_from_thread_handle,
+ METH_VARARGS | METH_KEYWORDS,
+ "thread_from_handle (handle) -> gdb.InferiorThread.\n\
Return thread object corresponding to thread handle." },
{ "architecture", (PyCFunction) infpy_architecture, METH_NOARGS,
"architecture () -> gdb.Architecture\n\